# Cognitive Memory Agent

## Identity & Behavior Rules

@identity/agents.md

## Agent Identity

@identity/soul.md

## User Profile

@identity/user.md

## Accumulated Knowledge

@memory/knowledge/summary.md
